Range-v3: ranges::v3::intersperse_view< Rng > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Instances and minimal complete definitions | Public Member Functions | List of all members
ranges::v3::intersperse_view< Rng > Struct Template Reference
Views
Inheritance diagram for ranges::v3::intersperse_view< Rng >:

## Public Member Functions
constexpr | intersperse_view (Rng rng, range_value_type_t< Rng > val) noexcept(std::is_nothrow_constructible< typename intersperse_view::view_adaptor, Rng >::value &&std::is_nothrow_move_constructible< range_value_type_t< Rng >>::value)
constexpr range_size_type_t< Rng > | size () const noexcept(noexcept(ranges::size(std::declval< Rng const &>())))
range_size_type_t< Rng > | size () noexcept(noexcept(ranges::size(std::declval< Rng &>())))
Public Member Functions inherited from ranges::v3::view_adaptor< Derived, BaseRng, Cardinality >
base_range_t & | base () noexcept
constexpr base_range_t const & | base () const noexcept
view_adaptor & | operator= (view_adaptor &&)=default
view_adaptor & | operator= (view_adaptor const &)=default
| view_adaptor (view_adaptor &&)=default
| view_adaptor (view_adaptor const &)=default
constexpr | view_adaptor (BaseRng &&rng)
Public Member Functions inherited from ranges::v3::view_facade< Derived, Cardinality >
template<typename D = Derived, requires = (Same<D, Derived>())>
detail::facade_iterator_t< D > | begin ()
| Let `d` be `static_cast<Derived &>(*this)`. Let `b` be `std::as_const(d).begin_cursor()` if that expression is well-formed; otherwise, let `b` be `d.begin_cursor()`. Let `B` be the type of `b`. More...
template<typename D = Derived, requires = (Same<D, Derived>())>
detail::facade_iterator_t< D const > | begin () const
template<typename D = Derived, requires = (Same<D, Derived>())>
detail::facade_sentinel_t< D > | end ()
| Let `d` be `static_cast<Derived &>(*this)`. Let `e` be `std::as_const(d).end_cursor()` if that expression is well-formed; otherwise, let `e` be `d.end_cursor()`. Let `E` be the type of `e`. More...
template<typename D = Derived, requires = (Same<D, Derived>())>
detail::facade_sentinel_t< D const > | end () const
Public Member Functions inherited from ranges::v3::view_interface< Derived, Cardinality >
template<typename D = Derived, requires = (Same<D, Derived>() && RandomAccessRange<D>() && SizedRange<D>())>
auto | at (range_difference_type_t< D > n) -> decltype(std::declval< D &>().begin()[n])
| Returns a reference to the element at specified location pos, with bounds checking.
template<typename D = Derived, requires = (Same<D, Derived>() && RandomAccessRange<D const>() && SizedRange<D const>())>
auto | at (range_difference_type_t< D > n) const -> decltype(std::declval< D const &>().begin()[n])
template<typename D = Derived, requires = (Same<D, Derived>() && BoundedRange<D>() && BidirectionalRange<D>())>
range_reference_t< D > | back ()
| Access the last element in a range:
template<typename D = Derived, requires = (Same<D, Derived>() && BoundedRange<D const>() && BidirectionalRange<D const>())>
range_reference_t< D const > | back () const
constexpr bool | empty () const noexcept
template<typename D = Derived, requires = (Same<D, Derived>() && Cardinality < 0 && ForwardRange<D const>())>
constexpr bool | empty () const noexcept(noexcept(bool(ranges::begin(std::declval< D const &>())==ranges::end(std::declval< D const &>()))))
template<typename D = Derived, requires = (Same<D, Derived>() && ForwardRange<D>())>
range_reference_t< D > | front ()
| Access the first element in a range:
template<typename D = Derived, requires = (Same<D, Derived>() && ForwardRange<D const>())>
range_reference_t< D const > | front () const
template<typename D = Derived, requires = (Same<D, Derived>()), typename = decltype(ranges::empty(std::declval<D const &>()))>
constexpr | operator bool () const noexcept(noexcept(ranges::empty(std::declval< D const &>())))
template<typename Container , typename D = Derived, typename = typename Container::allocator_type, requires = (detail::ConvertibleToContainer<D, Container>())>
| operator Container ()
| Implicit conversion to something that looks like a container.
template<typename Container , typename D = Derived, typename = typename Container::allocator_type, requires = (detail::ConvertibleToContainer<D const, Container>())>
| operator Container () const
template<typename D = Derived, requires = (Same<D, Derived>())>
constexpr auto | operator! () const noexcept(noexcept(decltype(ranges::empty(std::declval< D const &>()))(ranges::empty(std::declval< D const &>())))) -> decltype(ranges::empty(std::declval< D const &>()))
view_interface & | operator= (view_interface &&)=default
view_interface & | operator= (view_interface const &)=default
template<typename D = Derived, requires = (Same<D, Derived>() && RandomAccessRange<D>())>
auto | operator[] (range_difference_type_t< D > n) -> decltype(std::declval< D &>().begin()[n])
| Simple indexing:
template<typename D = Derived, requires = (Same<D, Derived>() && RandomAccessRange<D const>())>
auto | operator[] (range_difference_type_t< D > n) const -> decltype(std::declval< D const &>().begin()[n])
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &-> decltype(std::declval< Slice >()(std::declval< D &>(), offs.from, offs.to))
| Python-ic slicing:
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const &>(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, requires = (Same<D, Derived>())>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to))
template<typename D = Derived, requires = (Same<D, Derived>() && Cardinality >= 0)>
constexpr range_size_type_t< D > | size () const noexcept
| Access the size of the range, if it can be determined:
template<typename D = Derived, requires = (Same<D, Derived>() && Cardinality < 0 && SizedSentinel<sentinel_t<D const>, iterator_t<D const>>() && ForwardRange<D const>())>
constexpr range_size_type_t< D > | size () const
| view_interface (view_interface &&)=default
| view_interface (view_interface const &)=default

## Additional Inherited Members
Protected Member Functions inherited from ranges::v3::view_facade< Derived, Cardinality >
Derived | begin_cursor () const
constexpr default_sentinel | end_cursor () const
Protected Member Functions inherited from ranges::v3::view_interface< Derived, Cardinality >
Derived & | derived () noexcept
constexpr Derived const & | derived () const noexcept
Protected Attributes inherited from ranges::v3::view_facade< Derived, Cardinality >
friend | range_access